@@ -212,18 +212,28 @@ void dot_neato_layout_cb (GtkWidget *button, PluginInstance *inst)
     layout_type = CIRCO_LAYOUT;
   }
 
+#ifndef HAVE_CGRAPH
   aginit();
+#endif
   if (gvc == NULL)
     gvc = gvContext();
 
   /*-- create a new empty graph --*/
+#ifdef HAVE_CGRAPH
+  graph = agopen("graph", Agdirected, NULL);
+#else
   graph = agopen("graph", kind);
-
+#endif
+  
   /*-- create new nodes, add to graph --*/
   for (i=0; i<nvisible; i++) {
     m = visible[i];
     name = (gchar *) g_array_index (d->rowlab, gchar *, m);
+#ifdef HAVE_CGRAPH
+    agnode(graph, name, 1);
+#else
     agnode(graph, name);
+#endif    
   }
 
   intv = (gint *) g_malloc (e->edge.n * sizeof(gint));
@@ -245,7 +255,11 @@ void dot_neato_layout_cb (GtkWidget *button, PluginInstance *inst)
 
     /*-- if head and tail are both in the visible subset --*/
     if (head && tail) {
+#ifdef HAVE_CGRAPH
+      edge = agedge(graph, tail, head, "", 1);
+#else
       edge = agedge(graph, tail, head);
+#endif
       intv[nedges] = i;
       edgev[nedges] = edge;
       nedges++;
@@ -267,9 +281,14 @@ void dot_neato_layout_cb (GtkWidget *button, PluginInstance *inst)
       m = visible[i];
       name = (gchar *) g_array_index (d->rowlab, gchar *, m);
       node = agfindnode (graph, name);
+#ifdef HAVE_CGRAPH
+      pos[i][0] = ND_coord(node).x;
+      pos[i][1] = ND_coord(node).y;
+#else
       pos[i][0] = node->u.coord.x;
       pos[i][1] = node->u.coord.y;
-    }
+#endif
+    } 
 
   } else if (layout_type == TWOPI_LAYOUT) {
     Agnode_t *ctr = 0;
@@ -280,9 +299,15 @@ void dot_neato_layout_cb (GtkWidget *button, PluginInstance *inst)
         (gchar *) g_array_index (d->rowlab, gchar *, 
 				 (gl->centerNodeIndex)));
     }
-
+    
     if (ctr)
-      agsafeset (graph, "root", ctr->name, NULL);
+      agsafeset (graph, "root",
+#ifdef HAVE_CGRAPH
+                 agnameof(ctr),
+#else
+                 ctr->name,
+#endif
+                 NULL);
     gvLayout (gvc, graph, "twopi");
 
     /*-- add variables generated by the layout algorithm --*/
@@ -312,11 +337,19 @@ void dot_neato_layout_cb (GtkWidget *button, PluginInstance *inst)
 
     if (gl->neato_dim > 2) {
         char buf[20];
-        sym = agfindattr(graph,"dim");   
+#ifdef HAVE_CGRAPH
+        sym = agattrsym(graph,"dim");
+        if (!sym)
+          sym = agattr(graph, AGRAPH, "dim", "");
+        sprintf (buf, "%d", gl->neato_dim);
+        agxset(graph,  sym, buf);
+#else
+        sym = agfindattr(graph,"dim");
         if (!sym)
           sym = agraphattr(graph,"dim","");
         sprintf (buf, "%d", gl->neato_dim);
-        agxset(graph, sym->index, buf);
+        agxset(graph,  sym->index, buf);
+#endif
     }
     /* rather than doing the previous, you can take neato_init_graph
      * apart as you originally did. We should probably put in some
@@ -334,7 +367,7 @@ void dot_neato_layout_cb (GtkWidget *button, PluginInstance *inst)
       model = "subset";
       modelchar = 'b';
     }
-    agsafeset (graph, "model", model, NULL);
+    agsafeset (graph, "model", model, "");
 
     /* In place of MODE_MAJOR, you could use MODE_KK which is the old neato */
     if (gl->neato_use_edge_length_p && weightvar >= 0) {
@@ -351,7 +384,11 @@ void dot_neato_layout_cb (GtkWidget *button, PluginInstance *inst)
         pos[i][k] = (gdouble) ND_pos(node)[k]; /* node->u.pos[k];*/
       /*-- may want to set u.width, u.height to very small values --*/
       /*-- I see no effect, though ... dfs --*/
+#ifdef HAVE_CGRAPH
+      ND_width(node) = ND_height(node) = .001;
+#else
       node->u.width = node->u.height = .001;
+#endif
     }
 #ifdef DEBUG
     f = fopen ("test.out", "w");
