@@ -4,7 +4,7 @@
  * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
  *
  * ggobi is free software; you may use, redistribute, and/or modify it
- * under the terms of the Common Public License, which is distributed
+ * under the terms of the Eclipse Public License, which is distributed
  * with the source code and displayed on the ggobi web site, 
  * www.ggobi.org.  For more information, contact the authors:
  *
@@ -698,10 +698,10 @@ ValidateGGobiRef (ggobid * gg, gboolean fatal)
   }
 
   if (fatal) {
-    g_error (error_msg);
+    g_error ("%s", error_msg);
   }
   else
-    g_critical (error_msg);
+    g_critical ("%s", error_msg);
 
   return (NULL);
 }
@@ -718,9 +718,9 @@ ValidateDatadRef (GGobiData * d, ggobid * gg, gboolean fatal)
   }
 
   if (fatal)
-    g_error (error_msg);
+    g_error ("%s", error_msg);
   else
-    g_critical (error_msg);
+    g_critical ("%s", error_msg);
 
   return (NULL);
 }
@@ -739,9 +739,9 @@ ValidateDisplayRef (displayd * d, ggobid * gg, gboolean fatal)
   }
 
   if (fatal)
-    g_error (error_msg);
+    g_error ("%s", error_msg);
   else
-    g_critical (error_msg);
+    g_critical ("%s", error_msg);
 
   return (NULL);
 }
